==> haskell-shakespeare-2.0.15-40-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-shakespeare.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: shakespeare
version: 2.0.15
id: shakespeare-2.0.15-3H5JQk4jEjUGtkWOinjF7u
key: shakespeare-2.0.15-3H5JQk4jEjUGtkWOinjF7u
license: MIT
maintainer: Michael Snoyman <michael@snoyman.com>
author: Michael Snoyman <michael@snoyman.com>
stability: Stable
homepage: http://www.yesodweb.com/book/shakespearean-templates
synopsis: A toolkit for making compile-time interpolated templates
description:
    Shakespeare is a family of type-safe, efficient template languages. Shakespeare templates are expanded at compile-time, ensuring that all interpolated variables are in scope. Variables are interpolated according to their type through a typeclass.
    .
    Shakespeare templates can be used inline with a quasi-quoter or in an external file.
    .
    Note there is no dependency on haskell-src-extras. Instead Shakespeare believes logic should stay out of templates and has its own minimal Haskell parser.
    .
    Packages that use this: xml-hamlet
    .
    Please see the documentation at <http://www.yesodweb.com/book/shakespearean-templates> for more details.
category: Web, Yesod
abi: d46bfc608249f7bc49265f801fa2e248
exposed: True
exposed-modules:
    Text.Cassius Text.Coffee Text.Hamlet Text.Hamlet.RT
    Text.Hamlet.Runtime Text.Internal.Css Text.Internal.CssCommon
    Text.Julius Text.Lucius Text.Roy Text.Shakespeare
    Text.Shakespeare.Base Text.Shakespeare.I18N Text.Shakespeare.Text
    Text.TypeScript
hidden-modules: Text.Hamlet.Parse Text.MkSizeType
                Text.IndentToBrace
import-dirs: /usr/lib/ghc-8.4.3/site-local/shakespeare-2.0.15
library-dirs: /usr/lib/ghc-8.4.3/site-local/shakespeare-2.0.15
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/shakespeare-2.0.15
hs-libraries: HSshakespeare-2.0.15-3H5JQk4jEjUGtkWOinjF7u
depends:
    base-4.11.1.0 time-1.8.0.2 containers-0.5.11.0
    template-haskell-2.13.0.0 parsec-3.1.13.0 text-1.2.3.0
    process-1.6.3.0 ghc-prim-0.5.2.0 bytestring-0.10.8.2
    directory-1.3.1.5 aeson-1.3.1.1-IVr04sg3p2P8j1rEsumT73
    blaze-markup-0.8.2.1-FFkiru1HsegAfMrnqJMDug
    blaze-html-0.9.1.1-20cHaEyBGNsGxpPmCtOdMq
    exceptions-0.10.0-7epDYg20HTz9YX9m9nzGfO transformers-0.5.5.0
    vector-0.12.0.1-1fezwShzdEfG3Hp1Pmvjkq
    unordered-containers-0.2.9.0-4xkK4TVeOzU5CT7vUnH40Y
    scientific-0.3.6.2-KcBBbCjUUZZKnRSUL2OTul
abi-depends: base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             time-1.8.0.2=976962cc6498b843f1efb5bef740838e
             containers-0.5.11.0=7795138514357bd2e41eaf59b6cfce4f
             template-haskell-2.13.0.0=1ce4a454c5861830bbdedc46baa462f3
             parsec-3.1.13.0=a963888603f65e0a8f63f07fffd516d6
             text-1.2.3.0=be4c3e1c57cff1d501eb0e876706a48d
             process-1.6.3.0=abb0cfe39ff8617a198f540a7db854a9
             ghc-prim-0.5.2.0=39dc2488936298f474639901f9105eec
             bytestring-0.10.8.2=76943c00398d547fb172e56c2f93c635
             directory-1.3.1.5=e563da47c8e71ee27761a9b9d172f1ec
             aeson-1.3.1.1-IVr04sg3p2P8j1rEsumT73=a6f953f9dda8218f3e00f48fbc968e32
             blaze-markup-0.8.2.1-FFkiru1HsegAfMrnqJMDug=18a52ecde9bf04c66bdf9a0cefc08348
             blaze-html-0.9.1.1-20cHaEyBGNsGxpPmCtOdMq=7047caae57386baf49e8a9f0b929d8b4
             exceptions-0.10.0-7epDYg20HTz9YX9m9nzGfO=87ba3c1011ac70bcfb17ce2e39a2e1bb
             transformers-0.5.5.0=633c3e5ec737c360775b452ce9aa1e0b
             vector-0.12.0.1-1fezwShzdEfG3Hp1Pmvjkq=2d4c17574909e037fa0256847c747647
             unordered-containers-0.2.9.0-4xkK4TVeOzU5CT7vUnH40Y=35805d13add6a65c87fb8fb413d93b58
             scientific-0.3.6.2-KcBBbCjUUZZKnRSUL2OTul=dc9b33f81f401bd0ab050d9bb851ae71
haddock-interfaces: /usr/share/doc/haskell-shakespeare/html/shakespeare.haddock
haddock-html: /usr/share/doc/haskell-shakespeare/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-shakespeare-2.0.15-41-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-shakespeare.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: shakespeare
version: 2.0.15
id: shakespeare-2.0.15-L3w2n6v52yeBUnK8PkXYWa
key: shakespeare-2.0.15-L3w2n6v52yeBUnK8PkXYWa
license: MIT
maintainer: Michael Snoyman <michael@snoyman.com>
author: Michael Snoyman <michael@snoyman.com>
stability: Stable
homepage: http://www.yesodweb.com/book/shakespearean-templates
synopsis: A toolkit for making compile-time interpolated templates
description:
    Shakespeare is a family of type-safe, efficient template languages. Shakespeare templates are expanded at compile-time, ensuring that all interpolated variables are in scope. Variables are interpolated according to their type through a typeclass.
    .
    Shakespeare templates can be used inline with a quasi-quoter or in an external file.
    .
    Note there is no dependency on haskell-src-extras. Instead Shakespeare believes logic should stay out of templates and has its own minimal Haskell parser.
    .
    Packages that use this: xml-hamlet
    .
    Please see the documentation at <http://www.yesodweb.com/book/shakespearean-templates> for more details.
category: Web, Yesod
abi: edc835412f67ebdb048a711ac8b91b43
exposed: True
exposed-modules:
    Text.Cassius Text.Coffee Text.Hamlet Text.Hamlet.RT
    Text.Hamlet.Runtime Text.Internal.Css Text.Internal.CssCommon
    Text.Julius Text.Lucius Text.Roy Text.Shakespeare
    Text.Shakespeare.Base Text.Shakespeare.I18N Text.Shakespeare.Text
    Text.TypeScript
hidden-modules: Text.Hamlet.Parse Text.MkSizeType
                Text.IndentToBrace
import-dirs: /usr/lib/ghc-8.4.3/site-local/shakespeare-2.0.15
library-dirs: /usr/lib/ghc-8.4.3/site-local/shakespeare-2.0.15
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/shakespeare-2.0.15
hs-libraries: HSshakespeare-2.0.15-L3w2n6v52yeBUnK8PkXYWa
depends:
    base-4.11.1.0 time-1.8.0.2 containers-0.5.11.0
    template-haskell-2.13.0.0 parsec-3.1.13.0 text-1.2.3.0
    process-1.6.3.0 ghc-prim-0.5.2.0 bytestring-0.10.8.2
    directory-1.3.1.5 aeson-1.3.1.1-EBUC8UHBskq8l6BMagWOXf
    blaze-markup-0.8.2.1-FFkiru1HsegAfMrnqJMDug
    blaze-html-0.9.1.1-20cHaEyBGNsGxpPmCtOdMq
    exceptions-0.10.0-7epDYg20HTz9YX9m9nzGfO transformers-0.5.5.0
    vector-0.12.0.1-1fezwShzdEfG3Hp1Pmvjkq
    unordered-containers-0.2.9.0-4xkK4TVeOzU5CT7vUnH40Y
    scientific-0.3.6.2-KcBBbCjUUZZKnRSUL2OTul
abi-depends: base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             time-1.8.0.2=976962cc6498b843f1efb5bef740838e
             containers-0.5.11.0=7795138514357bd2e41eaf59b6cfce4f
             template-haskell-2.13.0.0=1ce4a454c5861830bbdedc46baa462f3
             parsec-3.1.13.0=a963888603f65e0a8f63f07fffd516d6
             text-1.2.3.0=be4c3e1c57cff1d501eb0e876706a48d
             process-1.6.3.0=abb0cfe39ff8617a198f540a7db854a9
             ghc-prim-0.5.2.0=39dc2488936298f474639901f9105eec
             bytestring-0.10.8.2=76943c00398d547fb172e56c2f93c635
             directory-1.3.1.5=e563da47c8e71ee27761a9b9d172f1ec
             aeson-1.3.1.1-EBUC8UHBskq8l6BMagWOXf=099629a1e097a2a1a4c1ce1f1c4a7711
             blaze-markup-0.8.2.1-FFkiru1HsegAfMrnqJMDug=18a52ecde9bf04c66bdf9a0cefc08348
             blaze-html-0.9.1.1-20cHaEyBGNsGxpPmCtOdMq=7047caae57386baf49e8a9f0b929d8b4
             exceptions-0.10.0-7epDYg20HTz9YX9m9nzGfO=87ba3c1011ac70bcfb17ce2e39a2e1bb
             transformers-0.5.5.0=633c3e5ec737c360775b452ce9aa1e0b
             vector-0.12.0.1-1fezwShzdEfG3Hp1Pmvjkq=2d4c17574909e037fa0256847c747647
             unordered-containers-0.2.9.0-4xkK4TVeOzU5CT7vUnH40Y=35805d13add6a65c87fb8fb413d93b58
             scientific-0.3.6.2-KcBBbCjUUZZKnRSUL2OTul=dc9b33f81f401bd0ab050d9bb851ae71
haddock-interfaces: /usr/share/doc/haskell-shakespeare/html/shakespeare.haddock
haddock-html: /usr/share/doc/haskell-shakespeare/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
